==> nextcloud-app-mail-2.1.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/ar.js <==
OC.L10N.register(
    "mail",
    {
    "Important mail" : "البريد الهام",
    "Unread mail" : "البريد غير المقروء",
    "Important" : "مهم",
    "Work" : "العمل",
    "Personal" : "شخصي",
    "Later" : "لاحقا",
    "Mails" : "الرسائل",
    "Mail" : "البريد",
    "Auto" : "تلقائي",
    "Name" : "الإسم",
    "Mail address" : "عنوان البريد الإلكتروني",
    "Password" : "كلمة المرور",
    "Manual" : "يدوي",
    "IMAP Settings" : "إعدادات IMAP",
    "IMAP Host" : "مُضيف IMAP",
    "None" : "بلا",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "منفذ IMAP",
    "IMAP User" : "مستخدم IMAP",
    "IMAP Password" : "كلمة مرور IMAP",
    "SMTP Settings" : "إعدادات SMTP",
    "SMTP Host" : "مُضيف SMTP",
    "SMTP Port" : "منفذ SMTP",
    "SMTP User" : "مستخدم SMTP",
    "SMTP Password" : "كلمة مرور SMTP",
    "Save" : "حفظ",
    "Connect" : "اتصال",
    "Change name" : "تغيير الإسم",
    "Signature" : "التوقيع",
    "Mail server" : "خادم البريد",
    "Email address" : "عنوان البريد الإلكتروني",
    "Cancel" : "إلغاء",
    "Add mail account" : "أضف حساب بريدي",
    "Show keyboard shortcuts" : "اظهار اختصارات لوحة المفاتيح",
    "Select account" : "إختيار حساب",
    "Subject" : "الموضوع",
    "Upload attachment" : "رفع المرفقات",
    "Add attachment from Files" : "إضافة مرفقات مِن الملفات",
    "Enter a date" : "ادخل تاريخ",
    "Sending …" : "جار الإرسال",
    "Go back" : "العودة",
    "Retry" : "أعد المحاولة",
    "Message sent!" : "تم الإرسال الرسالة!",
    "Send" : "أرسل",
    "No sent mailbox configured. Please pick one in the account settings." : "لم يتم اعداد الرسائل في المرسلة في صندوق البريد. يرجى اختيار واحد في اعدادات الحساب.",
    "Choose a file to add as attachment" : "اختر ملف لإضافته كمرفق",
    "Choose a file to share as a link" : "اختر ملفا لمشاركته كرابط",
    "Draft: " : "المسودة:",
    "Unfavorite" : "غير مفضل",
    "Favorite" : "المفضلة",
    "Read" : "القراءة",
    "Unselect" : "إلغاء التحديد",
    "Select" : "تحديد",
    "Move" : "نقل",
    "More actions" : "إجراءات أخرى",
    "Edit as new message" : "تحرير كرسالة جديدة",
    "Create event" : "انشاء فعالية",
    "No trash mailbox configured" : "لم يتم اعداد سلة المحذوفات لصندوق البريد",
    "Could not delete message" : "لا يمكن حذف الرسالة",
    "Forward" : "إعادة توجيه ",
    "All day" : "اليوم بأكمله",
    "Create" : "إنشاء",
    "Comment" : "تعليق",
    "Accept" : "قبول",
    "Decline" : "رفض",
    "More options" : "مزيد من الخيارات",
    "Choose" : "إختر",
    "Other" : "آخر",
    "Reply" : "رد",
    "Import into calendar" : "إستيراد من التقويم",
    "Download attachment" : "تنزيل الملحق",
    "Save to Files" : "حفظ للـ الملفات",
    "Choose a folder to store the attachment in" : "اختر مجلد لتخزين المرفقات ",
    "Save all to Files" : "حفظ الجميع لـ الملفات",
    "The images have been blocked to protect your privacy." : "تم حجب هذه الصورة لحماية خصوصيتك",
    "Show images" : "عرض الصور",
    "Quota" : "الحصة",
    "Saving" : "جاري الحفظ ...",
    "Remove account" : "حذف حساب",
    "Loading …" : "جاري التحميل …",
    "Mark all as read" : "تحديد الكل كمقروء",
    "Edit name" : "تعديل الاسم",
    "Clear cache" : "مسح ذاكرة التخزين المؤقتة",
    "Delete mailbox" : "حذف صندوق البريد",
    "New message" : "رسالة جديدة",
    "Message" : "الرسالة",
    "Delete" : "حذف",
    "Copy to clipboard" : "نسخ الرابط",
    "Add" : "إضافة",
    "Search" : "بحث",
    "Disabled" : "معطّل",
    "Enabled" : "مفعلة",
    "Custom" : "مخصّص",
    "Set" : "تعيين",
    "Unset" : "غير محدد",
    "Add tag" : "إضافة وسما",
    "Mark as unread" : "تمييز كغير مقروء",
    "Mark as read" : "تمييز كمقروء",
    "Not found" : "غير موجود",
    "Remove" : "حذف",
    "(organizer)" : "(منظم)",
    "Untitled event" : "فعالية بدون اسم",
    "Reset" : "إعادة الضبط",
    "General" : "العامة",
    "User" : "المستخدم",
    "Host" : "المضيف",
    "Port" : "المنفذ",
    "Keyboard shortcuts" : "إختصارات لوحة المفاتيح",
    "Speed up your Mail experience with these quick shortcuts." : "سرّع تجربة بريدك مع هذه الإختصارات.",
    "Compose new message" : "إرسل رسالة جديدة",
    "Newer message" : "الرسائل الأحدث",
    "Older message" : "الرسائل الأقدم",
    "Toggle star" : "حدد النجوم",
    "Toggle unread" : "حدد الغير مقروء",
    "Refresh" : "تحديث",
    "Connect your mail account" : "تحديث",
    "All" : "الكل",
    "Archive" : "الأرشيف",
    "Drafts" : "المسودات",
    "Favorites" : "المفضلات",
    "All inboxes" : "جميع الوارد",
    "Inbox" : "صندوق الوارد",
    "Junk" : "عشوائي",
    "Sent" : "أرسلت",
    "Trash" : "سلة المحذوفات",
    "Error while sharing file" : "خطأ اثناء مشاركة ملف",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Nextcloud Mail" : "بريد ناكست كلاود",
    "Attachments were not copied. Please add them manually." : "المرفقات لم يتم نسخها. يرجى اضافتها يدويا.",
    "Message sent" : "تم إرسال الرسالة ",
    "Could not load {tag}{name}{endtag}" : "تعذر تحميل {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "حدث خطأ ما عند تحميل {tag}{name}{endtag}",
    "Could not load your message" : "تعذرت عملية تحميل رسالتك",
    "Could not load the message" : "تعذرت عملية تحميل الرسالة",
    "Error loading message" : "حدث خطأ خلال تحميل الرسالة",
    "Forwarding to %s" : "تمرير إلى %s",
    "Click here if you are not automatically redirected within the next few seconds." : "إضغط هنا إذا لم يتم إعادة توجيهك تلقائياً بعد عدة ثواني.",
    "Redirect" : "إعادة توجيه",
    "The link leads to %s" : "الرابط يؤدي إل %s",
    "Continue to %s" : "أكمل إلى %s"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-app-mail-2.2.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/ar.js <==
OC.L10N.register(
    "mail",
    {
    "Important mail" : "البريد الهام",
    "Unread mail" : "البريد غير المقروء",
    "Important" : "مهم",
    "Work" : "العمل",
    "Personal" : "شخصي",
    "Later" : "لاحقا",
    "Mails" : "الرسائل",
    "Mail" : "البريد",
    "Auto" : "تلقائي",
    "Name" : "الإسم",
    "Mail address" : "عنوان البريد الإلكتروني",
    "Password" : "كلمة المرور",
    "Manual" : "يدوي",
    "IMAP Settings" : "إعدادات IMAP",
    "IMAP Host" : "مُضيف IMAP",
    "None" : "بلا",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "منفذ IMAP",
    "IMAP User" : "مستخدم IMAP",
    "IMAP Password" : "كلمة مرور IMAP",
    "SMTP Settings" : "إعدادات SMTP",
    "SMTP Host" : "مُضيف SMTP",
    "SMTP Port" : "منفذ SMTP",
    "SMTP User" : "مستخدم SMTP",
    "SMTP Password" : "كلمة مرور SMTP",
    "Save" : "حفظ",
    "Connect" : "اتصال",
    "Change name" : "تغيير الإسم",
    "Signature" : "التوقيع",
    "Mail server" : "خادم البريد",
    "Email address" : "عنوان البريد الإلكتروني",
    "Cancel" : "إلغاء",
    "Add mail account" : "أضف حساب بريدي",
    "Show keyboard shortcuts" : "اظهار اختصارات لوحة المفاتيح",
    "Select account" : "إختيار حساب",
    "Subject" : "الموضوع",
    "Upload attachment" : "رفع المرفقات",
    "Add attachment from Files" : "إضافة مرفقات مِن الملفات",
    "Enter a date" : "ادخل تاريخ",
    "Sending …" : "جار الإرسال",
    "Go back" : "العودة",
    "Retry" : "أعد المحاولة",
    "Message sent!" : "تم الإرسال الرسالة!",
    "Send" : "أرسل",
    "No sent mailbox configured. Please pick one in the account settings." : "لم يتم اعداد الرسائل في المرسلة في صندوق البريد. يرجى اختيار واحد في اعدادات الحساب.",
    "Choose a file to add as attachment" : "اختر ملف لإضافته كمرفق",
    "Choose a file to share as a link" : "اختر ملفا لمشاركته كرابط",
    "No messages" : "لاتوجد رسائل",
    "Draft: " : "المسودة:",
    "Unfavorite" : "غير مفضل",
    "Favorite" : "المفضلة",
    "Read" : "القراءة",
    "Unselect" : "إلغاء التحديد",
    "Select" : "تحديد",
    "Move" : "نقل",
    "More actions" : "إجراءات أخرى",
    "Edit as new message" : "تحرير كرسالة جديدة",
    "Create event" : "انشاء فعالية",
    "No trash mailbox configured" : "لم يتم اعداد سلة المحذوفات لصندوق البريد",
    "Could not delete message" : "لا يمكن حذف الرسالة",
    "Forward" : "إعادة توجيه ",
    "All day" : "اليوم بأكمله",
    "Create" : "إنشاء",
    "Comment" : "تعليق",
    "Accept" : "قبول",
    "Decline" : "رفض",
    "More options" : "مزيد من الخيارات",
    "Choose" : "إختر",
    "Other" : "آخر",
    "Reply" : "رد",
    "Import into calendar" : "إستيراد من التقويم",
    "Download attachment" : "تنزيل الملحق",
    "Save to Files" : "حفظ للـ الملفات",
    "Choose a folder to store the attachment in" : "اختر مجلد لتخزين المرفقات ",
    "Save all to Files" : "حفظ الجميع لـ الملفات",
    "The images have been blocked to protect your privacy." : "تم حجب هذه الصورة لحماية خصوصيتك",
    "Show images" : "عرض الصور",
    "Quota" : "الحصة",
    "Saving" : "جاري الحفظ ...",
    "Remove account" : "حذف حساب",
    "Loading …" : "جاري التحميل …",
    "Mark all as read" : "تحديد الكل كمقروء",
    "Edit name" : "تعديل الاسم",
    "Clear cache" : "مسح ذاكرة التخزين المؤقتة",
    "Delete mailbox" : "حذف صندوق البريد",
    "New message" : "رسالة جديدة",
    "Message" : "الرسالة",
    "Delete" : "حذف",
    "Copy to clipboard" : "نسخ الرابط",
    "Add" : "إضافة",
    "Tags" : "الوسوم",
    "Clear" : "مسح ",
    "Search" : "بحث",
    "Date" : "التاريخ ",
    "Disabled" : "معطّل",
    "Enabled" : "مفعلة",
    "Custom" : "مخصّص",
    "Set" : "تعيين",
    "Unset" : "غير محدد",
    "Add tag" : "إضافة وسما",
    "Not found" : "غير موجود",
    "Mark as unread" : "تمييز كغير مقروء",
    "Mark as read" : "تمييز كمقروء",
    "Remove" : "حذف",
    "(organizer)" : "(منظم)",
    "Untitled event" : "فعالية بدون اسم",
    "Reset" : "إعادة الضبط",
    "Client ID" : "معرف العميل",
    "General" : "العامة",
    "User" : "المستخدم",
    "Host" : "المضيف",
    "Port" : "المنفذ",
    "Account connected" : "الحساب متصل",
    "Keyboard shortcuts" : "إختصارات لوحة المفاتيح",
    "Speed up your Mail experience with these quick shortcuts." : "سرّع تجربة بريدك مع هذه الإختصارات.",
    "Compose new message" : "إرسل رسالة جديدة",
    "Newer message" : "الرسائل الأحدث",
    "Older message" : "الرسائل الأقدم",
    "Toggle star" : "حدد النجوم",
    "Toggle unread" : "حدد الغير مقروء",
    "Refresh" : "تحديث",
    "Connect your mail account" : "تحديث",
    "All" : "الكل",
    "Archive" : "الأرشيف",
    "Drafts" : "المسودات",
    "Favorites" : "المفضلات",
    "All inboxes" : "جميع الوارد",
    "Inbox" : "صندوق الوارد",
    "Junk" : "عشوائي",
    "Sent" : "أرسلت",
    "Trash" : "سلة المحذوفات",
    "Error while sharing file" : "خطأ اثناء مشاركة ملف",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Nextcloud Mail" : "بريد ناكست كلاود",
    "Attachments were not copied. Please add them manually." : "المرفقات لم يتم نسخها. يرجى اضافتها يدويا.",
    "Message sent" : "تم إرسال الرسالة ",
    "Could not load {tag}{name}{endtag}" : "تعذر تحميل {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "حدث خطأ ما عند تحميل {tag}{name}{endtag}",
    "Could not load your message" : "تعذرت عملية تحميل رسالتك",
    "Could not load the message" : "تعذرت عملية تحميل الرسالة",
    "Error loading message" : "حدث خطأ خلال تحميل الرسالة",
    "Forwarding to %s" : "تمرير إلى %s",
    "Click here if you are not automatically redirected within the next few seconds." : "إضغط هنا إذا لم يتم إعادة توجيهك تلقائياً بعد عدة ثواني.",
    "Redirect" : "إعادة توجيه",
    "The link leads to %s" : "الرابط يؤدي إل %s",
    "Continue to %s" : "أكمل إلى %s"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
